@@ -6,31 +6,58 @@ import tempfile
 import time
 import types
 import typing as t
+import warnings
 import weakref
 from enum import Enum
 from pathlib import Path
 
 import httpx
 
-from nats_tools.generator import ConfigGenerator
 from nats_tools.monitor import NATSMonitor
+from nats_tools.templates import ConfigGenerator
 
 DEFAULT_BIN_DIR = Path.home().joinpath("nats-server").absolute()
 
 
-class Signal(Enum):
-    # Kill the process immediatley
-    KILL = signal.SIGKILL
-    # Kills the process immediately and perform a core dump
-    QUIT = signal.SIGQUIT
-    # Stops the server grafefully
-    STOP = signal.SIGTERM
-    # Reopens the log file for log rotation
-    REOPEN = signal.SIGUSR1
-    # Reload server configuration
-    RELOAD = signal.SIGHUP
-    # Stops the server after evicting all clients
-    LDM = signal.SIGUSR2
+class InvalidWindowsSignal(Enum):
+    SIGKILL = "KILL"
+    SIGQUIT = "QUIT"
+    SIGHUP = "HUP"
+    SIGUSR1 = "USR1"
+    SIGUSR2 = "USR2"
+
+
+if os.name == "nt":
+
+    class Signal(Enum):
+        # Kill the process immediatley
+        KILL = InvalidWindowsSignal.SIGKILL
+        # Kills the process immediately and perform a core dump
+        QUIT = InvalidWindowsSignal.SIGKILL
+        # Stops the server grafefully
+        STOP = signal.SIGTERM
+        # Reopens the log file for log rotation
+        REOPEN = InvalidWindowsSignal.SIGUSR1
+        # Reload server configuration
+        RELOAD = InvalidWindowsSignal.SIGHUP
+        # Stops the server after evicting all clients
+        LDM = InvalidWindowsSignal.SIGUSR2
+
+else:
+
+    class Signal(Enum):  # type: ignore[no-redef]
+        # Kill the process immediatley
+        KILL = signal.SIGKILL
+        # Kills the process immediately and perform a core dump
+        QUIT = signal.SIGQUIT
+        # Stops the server grafefully
+        STOP = signal.SIGTERM
+        # Reopens the log file for log rotation
+        REOPEN = signal.SIGUSR1
+        # Reload server configuration
+        RELOAD = signal.SIGHUP
+        # Stops the server after evicting all clients
+        LDM = signal.SIGUSR2
 
 
 class NATSD:
@@ -43,7 +70,7 @@ class NATSD:
         server_tags: t.Optional[t.Dict[str, str]] = None,
         user: t.Optional[str] = None,
         password: t.Optional[str] = None,
-        users: t.List[t.Dict[str, t.Any]] = None,
+        users: t.Optional[t.List[t.Dict[str, t.Any]]] = None,
         token: t.Optional[str] = None,
         http_port: int = 8222,
         debug: t.Optional[bool] = None,
@@ -87,7 +114,7 @@ class NATSD:
         system_account_jwt: t.Optional[str] = None,
         allow_delete_jwt: t.Optional[bool] = None,
         compare_jwt_interval: t.Optional[str] = None,
-        resolver_preload: t.Dict[str, str] = None,
+        resolver_preload: t.Optional[t.Dict[str, str]] = None,
         config_file: t.Union[str, Path, None] = None,
         max_cpus: t.Optional[float] = None,
         start_timeout: float = 1,
@@ -245,6 +272,11 @@ class NATSD:
         self.proc: t.Optional["subprocess.Popen[bytes]"] = None
         self.monitor = NATSMonitor(f"http://{self.address}:{self.http_port}")
 
+    def is_alive(self) -> bool:
+        if self.proc is None:
+            return False
+        return self.proc.poll() is None
+
     def _cleanup_on_exit(self) -> None:
         if self.proc and self.proc.poll() is None:
             print(
@@ -364,7 +396,8 @@ class NATSD:
                     "[\033[0;33mDEBUG\033[0;0m] Server listening on %d was stopped."
                     % self.port
                 )
-        if self.proc and self.proc.returncode != 1:
+        expected = 15 if os.name == "nt" else 1
+        if self.proc and self.proc.returncode != expected:
             raise subprocess.CalledProcessError(
                 self.proc.returncode, cmd=self.proc.args
             )
@@ -392,10 +425,28 @@ class NATSD:
         status = self.proc.poll()
         if status is not None:
             raise subprocess.CalledProcessError(status, cmd=self.proc.args)
-        if not isinstance(sig, Signal):
-            sig = signal.Signals(sig)
+        if os.name != "nt":
+            if not isinstance(sig, Signal):
+                sig = signal.Signals(sig)
+                sig = Signal(sig)
+            os.kill(self.proc.pid, sig.value)
+        else:
             sig = Signal(sig)
-        os.kill(self.proc.pid, sig.value)
+            if isinstance(sig.value, InvalidWindowsSignal):
+                # Use a subprocess to explicitely call `nats-server --signal` which will handle signal correctly on Windows
+                if sig.value == InvalidWindowsSignal.SIGKILL:
+                    os.kill(self.proc.pid, signal.SIGINT)
+                elif sig.value == InvalidWindowsSignal.SIGQUIT:
+                    os.kill(self.proc.pid, signal.SIGBREAK)  # type: ignore[attr-defined]
+                elif sig.value == InvalidWindowsSignal.SIGHUP:
+                    warnings.warn("Config reload is not supported on Windows")
+                elif sig.value == InvalidWindowsSignal.SIGUSR1:
+                    warnings.warn("Log file roration is not supported on Windows")
+                elif sig.value == InvalidWindowsSignal.SIGUSR2:
+                    warnings.warn("Lame Duck Mode is not supported on Windows")
+                    os.kill(self.proc.pid, signal.SIGINT)
+            else:
+                os.kill(self.proc.pid, sig.value)
 
     def quit(self, timeout: t.Optional[float] = None) -> None:
         self.send_signal(Signal.QUIT)
